@@ -1,4 +1,4 @@
-dummify <- function(x, show.na=FALSE){
+dummify <- function(x, show.na=FALSE, keep.na=FALSE){
   if(!is.factor(x)){
     stop("variable needs to be a factor")
   }
@@ -11,5 +11,7 @@ dummify <- function(x, show.na=FALSE){
   attributes(out)$contrasts <- NULL
   if(show.na==FALSE)
     out <- out[,(colnames(out)=="NAFACTOR")==FALSE]
+  if(keep.na==TRUE)
+    out[x=="NAFACTOR",] <- matrix(NA, sum(x=="NAFACTOR"), dim(out)[2])
   out
 }
